@@ -1,4 +1,5 @@
 import json
+from json.decoder import JSONDecodeError
 
 from typing import List, Any
 from pathlib import Path
@@ -6,6 +7,23 @@ from pathlib import Path
 from pab.exceptions import MissingConfig
 
 
+def valid_config_found():
+    if CONFIG_FILE.is_file():
+        try:
+            with CONFIG_FILE.open("r") as fp:
+                json.load(fp)
+                return True
+        except JSONDecodeError:
+            pass
+    return False
+
+
+def override_config_with_defaults():
+    with CONFIG_FILE.open("w") as fp:
+        data = DEFAULTS_CONFIG_FILE.open("r").read()
+        fp.write(data)
+
+
 class MissingConfigFile(Exception):
     pass
 
@@ -18,8 +36,9 @@ class JSONConfig:
     def _read_datas(self) -> List[dict]:
         out = []
         for path in self.paths:
-            with open(path, "r") as fp:
-                out.append(json.load(fp))
+            if path.is_file():
+                with open(path, "r") as fp:
+                    out.append(json.load(fp))
         return out
     
     def get(self, name) -> Any:
@@ -65,14 +84,10 @@ KEY_FILE = Path("key.file")
 if not CONFIG_FILE.is_file:
     raise MissingConfigFile("Please create a config.json in your cwd.")
     
-APP_CONFIG = JSONConfig([CONFIG_FILE, DEFAULTS_CONFIG_FILE])
+try:
+    APP_CONFIG = JSONConfig([CONFIG_FILE, DEFAULTS_CONFIG_FILE])
+except Exception:
+    APP_CONFIG = JSONConfig([DEFAULTS_CONFIG_FILE])
 
 ENDPOINT = APP_CONFIG.get('endpoint')
-MY_ADDRESS = APP_CONFIG.get('myAddress')
 
-ALERTS_ON = APP_CONFIG.get("emails.enabled")
-ALERTS_HOST = APP_CONFIG.get("emails.host")
-ALERTS_PORT = APP_CONFIG.get("emails.port")
-ALERTS_ADDRESS = APP_CONFIG.get("emails.address")
-ALERTS_PASSWORD = APP_CONFIG.get("emails.password")
-ALERTS_RECIPIENT = APP_CONFIG.get("emails.recipient")
