@@ -1,12 +1,8 @@
-import sys
 import time
 import logging
 
-from typing import List, Union
-from datetime import datetime, timedelta
 
-from pab.strategy import BaseStrategy, RescheduleError, SpecificTimeRescheduleError
-from pab.config import DATETIME_FORMAT
+from pab.strategy import RescheduleError, SpecificTimeRescheduleError
 from pab.alert import alert_exception
 from pab.queue import Queue, QueueItem
 
