@@ -1,14 +1,11 @@
-import json
+import sys
 import time
 import logging
+import importlib
 
-from datetime import datetime, timedelta
 from pathlib import Path
-from typing import List
 
 from pab.blockchain import Blockchain
-from pab.config import DATETIME_FORMAT
-from pab.utils import *
 
 
 __all__ = [
@@ -16,9 +13,20 @@ __all__ = [
     "PABError",
     "RescheduleError",
     "SpecificTimeRescheduleError",
+    "import_local_strategies",
 ]
 
 
+def import_local_strategies():
+    try:
+        path = str(Path.cwd())
+        sys.path.append(path)
+        importlib.import_module("strategies")
+        sys.path.remove(path)
+    except ModuleNotFoundError as err:
+        raise RuntimeError("Can't find any strategies. Create a 'strategies' module in your CWD.") from err
+
+
 class BaseStrategy:
     """ Base class for strategies """
     def __init__(self, blockchain: Blockchain, name: str):
